@@ -17,7 +17,10 @@ CREATE TABLE IF NOT EXISTS `c_access_log` (
   `ktai_flag` int(11) NOT NULL default '0',
   `r_datetime` datetime NOT NULL default '0000-00-00 00:00:00',
   `ip_address` varchar(16) NOT NULL default '',
-  PRIMARY KEY  (`c_access_log_id`)
+  PRIMARY KEY  (`c_access_log_id`),
+  KEY `target_commu` (`target_c_commu_id`,`r_datetime`),
+  KEY `target_commu_topic` (`target_c_commu_topic_id`,`r_datetime`),
+  KEY `pagename` (`page_name`)
 ) TYPE=MyISAM;
 
 CREATE TABLE IF NOT EXISTS `c_admin_config` (
@@ -110,6 +113,8 @@ CREATE TABLE IF NOT EXISTS `c_commu` (
   `map_latitude` double NOT NULL default '0',
   `map_longitude` double NOT NULL default '0',
   `map_zoom` int(11) NOT NULL default '0',
+  `open_flag` tinyint(1) NOT NULL default '0',
+    `topic_authority_role` tinyint(2) NOT NULL default '0',
   PRIMARY KEY  (`c_commu_id`),
   KEY `c_commu_category_id` (`c_commu_category_id`),
   KEY `c_member_id_admin` (`c_member_id_admin`),
@@ -160,6 +165,7 @@ CREATE TABLE IF NOT EXISTS `c_commu_member` (
   `is_receive_mail` tinyint(1) NOT NULL default '0',
   `is_receive_mail_pc` int(11) NOT NULL default '0',
   `is_receive_message` int(11) NOT NULL default '1',
+  `c_commu_topic_admin` TINYINT(1) NOT NULL DEFAULT '0',
   PRIMARY KEY  (`c_commu_member_id`),
   KEY `c_commu_id` (`c_commu_id`),
   KEY `c_member_id` (`c_member_id`),
@@ -201,6 +207,8 @@ CREATE TABLE IF NOT EXISTS `c_commu_topic` (
   `invite_period` date NOT NULL default '0000-00-00',
   `event_flag` int(11) NOT NULL default '0',
   `e_datetime` datetime NOT NULL default '0000-00-00 00:00:00',
+  `open_flag` tinyint(1) NOT NULL default '0',
+  `etsuran_count` INT( 11 ) NOT NULL DEFAULT '0',
   PRIMARY KEY  (`c_commu_topic_id`),
   KEY `c_member_id` (`c_member_id`),
   KEY `c_commu_id` (`c_commu_id`),
@@ -311,9 +319,11 @@ CREATE TABLE IF NOT EXISTS `c_image` (
   `bin` longblob NOT NULL,
   `r_datetime` datetime NOT NULL default '0000-00-00 00:00:00',
   `type` text,
+  `c_member_id` int(11) NOT NULL default '0',
   PRIMARY KEY  (`c_image_id`),
   KEY `filename` (`filename`(100)),
-  KEY `r_datetime` (`r_datetime`)
+  KEY `r_datetime` (`r_datetime`),
+  KEY `c_member_id` (`c_member_id`)
 ) TYPE=MyISAM;
 
 CREATE TABLE IF NOT EXISTS `c_ktai_address_pre` (
@@ -738,6 +748,7 @@ CREATE TABLE IF NOT EXISTS `c_etsuran` (
  `c_etsuran_id` int(11) NOT NULL auto_increment,
  `c_member_id_from` int(11) NOT NULL default '0',
  `c_diary_id` int(11) NOT NULL default '0',
+ `c_commu_topic_id` INT( 11 ) NOT NULL DEFAULT '0',
  `r_datetime` datetime NOT NULL default '0000-00-00 00:00:00',
  PRIMARY KEY  (`c_etsuran_id`),
  KEY `c_member_id_from` (`c_member_id_from`),
@@ -745,10 +756,6 @@ CREATE TABLE IF NOT EXISTS `c_etsuran` (
  KEY `c_member_from_diary_id` (`c_member_id_from`,`c_diary_id`,`r_datetime`)
  ) type=MyISAM;
 
---
--- テーブルの構造 `c_ranking`
---
-
 CREATE TABLE IF NOT EXISTS `c_ranking` (
   `c_ranking_id` int(11) NOT NULL auto_increment,
   `ranking_date` date NOT NULL,
@@ -759,9 +766,6 @@ CREATE TABLE IF NOT EXISTS `c_ranking` (
   KEY `ranking_date` (`ranking_date`,`ranking_count`)
 ) TYPE=MyISAM AUTO_INCREMENT=1 ;
 
---
--- 日記のカテゴリー、タグの発想で
---
 CREATE TABLE IF NOT EXISTS `c_tags` (
   `c_tags_id` int(11) NOT NULL auto_increment,
   `c_tags_name` varchar(36) NOT NULL ,
@@ -784,11 +788,6 @@ CREATE TABLE IF NOT EXISTS `c_entry_tag` (
   KEY `c_entry_id_flag` (`c_entry_id`,`c_entry_flag`)
 ) TYPE=MyISAM AUTO_INCREMENT=1 ;
 
-
---
--- テーブルの構造 `c_dengon_comment`
---
-
 CREATE TABLE IF NOT EXISTS `c_dengon_comment` (
   `c_dengon_comment_id` int(11) NOT NULL auto_increment,
   `c_member_id_to` int(11) NOT NULL default '0',
@@ -808,17 +807,22 @@ CREATE TABLE IF NOT EXISTS `c_display_view` (
     PRIMARY KEY (`c_display_view_id`),
     KEY `is_money_flag` (`is_money_flag`)
 ) TYPE=MyISAM ;
+
+
 CREATE TABLE IF NOT EXISTS `c_admin_information` (
     `c_admin_information_id` int(11) NOT NULL auto_increment,
-    `subject` text NOT NULL default '',
-    `body` text NOT NULL default '',
-    `category` varchar(64) NOT NULL default '',
+    `subject` text NOT NULL,
+    `body` text NOT NULL,
+    `category` varchar(64) NOT NULL,
     `r_datetime` datetime NOT NULL default '0000-00-00 00:00:00',
     `c_view_flag` tinyint(1) NOT NULL default '0',
     `public_flag` tinyint(1) NOT NULL default '0',
+    `view_date` date NOT NULL default '0000-00-00',
     PRIMARY KEY (`c_admin_information_id`),
-    KEY `category` (`category`)
+    KEY `category` (`category`),
+    KEY `r_datetime_view_date` (`r_datetime`,`view_date`)
 ) TYPE=MyISAM ;
+
 CREATE TABLE IF NOT EXISTS `c_delete_member_data` (
  `c_delete_member_data_id` int(11) NOT NULL auto_increment,
  `c_member_id` int(11) NOT NULL ,
@@ -866,6 +870,242 @@ CREATE TABLE IF NOT EXISTS `c_inquiry` (
     KEY `category_flag` (`category_flag`)
 ) TYPE=MyISAM;
 
+CREATE TABLE IF NOT EXISTS `c_one_word` (
+    `c_one_word_id` int(11) NOT NULL auto_increment,
+    `c_member_id` int(11) NOT NULL ,
+    `c_one_word_id_to` int(11) NOT NULL default '0',
+    `comment` text NOT NULL ,
+    `r_datetime` datetime NOT NULL default '0000-00-00 00:00:00',
+    PRIMARY KEY  (`c_one_word_id`),
+    KEY `c_member_id_r_datetime` (`c_member_id`,`r_datetime`),
+    KEY `c_one_word_id_to` (`c_one_word_id_to`)
+) TYPE=MyISAM;
+
+
+CREATE TABLE IF NOT EXISTS `c_member_data` (
+  `c_member_data_id` int(11) NOT NULL auto_increment,
+  `c_member_id` int(11) NOT NULL default '0',
+  `diary_count` int(11) NOT NULL default '0',
+  `diary_comment_count` int(11) NOT NULL default '0',
+  `commu_count` int(11) NOT NULL default '0',
+  `topic_count` int(11) NOT NULL default '0',
+  `topic_comment_count` int(11) NOT NULL default '0',
+  `event_count` int(11) NOT NULL default '0',
+  `event_comment_count` int(11) NOT NULL default '0',
+  `message_send_count` int(11) NOT NULL default '0',
+  `message_resieve_count` int(11) NOT NULL default '0',
+  `image_count` int(11) NOT NULL default '0',
+  `movie_count` int(11) NOT NULL default '0',
+  `image_size` int(11) NOT NULL default '0',
+  `movie_size` int(11) NOT NULL default '0',
+  `friend_count` int(11) NOT NULL default '0',
+  `block_count` int(11) NOT NULL default '0',
+  `login_count` int(11) NOT NULL default '0',
+  `chenge_nickname_count` int(11) NOT NULL default '0',
+  `chenge_password_count` int(11) NOT NULL default '0',
+  `chenge_pcmail_count` int(11) NOT NULL default '0',
+  `chenge_mobilemail_count` int(11) NOT NULL default '0',
+  `member_rank` tinyint(2) NOT NULL default '0',
+  `member_point` int(11) NOT NULL default '0',
+  `created_at` datetime NOT NULL default '0000-00-00 00:00:00',
+  `updated_at` datetime NOT NULL default '0000-00-00 00:00:00',
+  `deleted_at` datetime NOT NULL default '0000-00-00 00:00:00',
+  PRIMARY KEY  (`c_member_data_id`),
+  KEY `c_member_id` (`c_member_id`)
+) TYPE=MyISAM ;
+
+
+CREATE TABLE IF NOT EXISTS `c_get_access` (
+  `c_get_access_id` int(11) NOT NULL auto_increment,
+  `c_member_id_to` int(11) NOT NULL default '0',
+  `c_member_id_from` int(11) NOT NULL default '0',
+  `access_count` int(11) NOT NULL default '0',
+  `created_at` datetime NOT NULL default '0000-00-00 00:00:00',
+  `updated_at` datetime NOT NULL default '0000-00-00 00:00:00',
+  `deleted_at` datetime NOT NULL default '0000-00-00 00:00:00',
+  PRIMARY KEY  (`c_get_access_id`),
+  KEY `c_member_id` (`c_member_id_to`),
+  KEY `c_member_from` (`c_member_id_from`)
+) TYPE=MyISAM;
+
+
+CREATE TABLE IF NOT EXISTS `c_image_commu` (
+  `c_image_commu_id` int(11) NOT NULL auto_increment,
+  `c_member_id` int(11) NOT NULL default '0',
+  `filename` text NOT NULL,
+  `filesize` int(11) NOT NULL default '0',
+  `filetype` char(3) NOT NULL default '',
+  `owner_id` int(11) NOT NULL default '0',
+  `comment` text,
+  `tags` varchar(64) default NULL,
+  `image_data` longblob,
+  `created_at` datetime NOT NULL default '0000-00-00 00:00:00',
+  `updated_at` datetime NOT NULL default '0000-00-00 00:00:00',
+  `deleted_at` datetime NOT NULL default '0000-00-00 00:00:00',
+  PRIMARY KEY  (`c_image_commu_id`),
+  KEY `c_member_id` (`c_member_id`),
+  KEY `filename_owner_id_sub` (`filename`(100),`owner_id`),
+  KEY `created_at` (`created_at`)
+) TYPE=MyISAM;
+
+
+CREATE TABLE IF NOT EXISTS `c_image_diary` (
+  `c_image_diary_id` int(11) NOT NULL auto_increment,
+  `c_member_id` int(11) NOT NULL default '0',
+  `filename` text NOT NULL,
+  `filesize` int(11) NOT NULL default '0',
+  `filetype` char(3) NOT NULL default '',
+  `owner_id` int(11) NOT NULL default '0',
+  `comment` text,
+  `tags` varchar(64) default NULL,
+  `image_data` longblob,
+  `created_at` datetime NOT NULL default '0000-00-00 00:00:00',
+  `updated_at` datetime NOT NULL default '0000-00-00 00:00:00',
+  `deleted_at` datetime NOT NULL default '0000-00-00 00:00:00',
+  PRIMARY KEY  (`c_image_diary_id`),
+  KEY `c_member_id` (`c_member_id`),
+  KEY `filename_owner_id_sub` (`filename`(100),`owner_id`),
+  KEY `created_at` (`created_at`)
+) TYPE=MyISAM;
+
+
+CREATE TABLE IF NOT EXISTS `c_image_diary_comment` (
+  `c_image_diary_comment_id` int(11) NOT NULL auto_increment,
+  `c_member_id` int(11) NOT NULL default '0',
+  `filename` text NOT NULL,
+  `filesize` int(11) NOT NULL default '0',
+  `filetype` char(3) NOT NULL default '',
+  `owner_id` int(11) NOT NULL default '0',
+  `comment` text,
+  `tags` varchar(64) default NULL,
+  `image_data` longblob,
+  `created_at` datetime NOT NULL default '0000-00-00 00:00:00',
+  `updated_at` datetime NOT NULL default '0000-00-00 00:00:00',
+  `deleted_at` datetime NOT NULL default '0000-00-00 00:00:00',
+  PRIMARY KEY  (`c_image_diary_comment_id`),
+  KEY `c_member_id` (`c_member_id`),
+  KEY `filename_owner_id_sub` (`filename`(100),`owner_id`),
+  KEY `created_at` (`created_at`)
+) TYPE=MyISAM;
+
+
+CREATE TABLE IF NOT EXISTS `c_image_topic_comment` (
+  `c_image_topic_comment_id` int(11) NOT NULL auto_increment,
+  `c_member_id` int(11) NOT NULL default '0',
+  `filename` text NOT NULL,
+  `filesize` int(11) NOT NULL default '0',
+  `filetype` char(3) NOT NULL default '',
+  `owner_id` int(11) NOT NULL default '0',
+  `comment` text,
+  `tags` varchar(64) default NULL,
+  `image_data` longblob,
+  `created_at` datetime NOT NULL default '0000-00-00 00:00:00',
+  `updated_at` datetime NOT NULL default '0000-00-00 00:00:00',
+  `deleted_at` datetime NOT NULL default '0000-00-00 00:00:00',
+  PRIMARY KEY  (`c_image_topic_comment_id`),
+  KEY `c_member_id` (`c_member_id`),
+  KEY `filename_owner_id_sub` (`filename`(100),`owner_id`),
+  KEY `created_at` (`created_at`)
+) TYPE=MyISAM;
+
+
+CREATE TABLE IF NOT EXISTS `c_image_message` (
+  `c_image_message_id` int(11) NOT NULL auto_increment,
+  `c_member_id` int(11) NOT NULL default '0',
+  `filename` text NOT NULL,
+  `filesize` int(11) NOT NULL default '0',
+  `filetype` char(3) NOT NULL default '',
+  `owner_id` int(11) NOT NULL default '0',
+  `comment` text,
+  `tags` varchar(64) default NULL,
+  `image_data` longblob,
+  `created_at` datetime NOT NULL default '0000-00-00 00:00:00',
+  `updated_at` datetime NOT NULL default '0000-00-00 00:00:00',
+  `deleted_at` datetime NOT NULL default '0000-00-00 00:00:00',
+  PRIMARY KEY  (`c_image_message_id`),
+  KEY `c_member_id` (`c_member_id`),
+  KEY `filename_owner_id_sub` (`filename`(100),`owner_id`),
+  KEY `created_at` (`created_at`)
+) TYPE=MyISAM;
+
+
+CREATE TABLE IF NOT EXISTS `c_image_profile` (
+  `c_image_profile_id` int(11) NOT NULL auto_increment,
+  `c_member_id` int(11) NOT NULL default '0',
+  `filename` text NOT NULL,
+  `filesize` int(11) NOT NULL default '0',
+  `filetype` char(3) NOT NULL default '',
+  `owner_id` int(11) NOT NULL default '0',
+  `comment` text,
+  `tags` varchar(64) default NULL,
+  `image_data` longblob,
+  `created_at` datetime NOT NULL default '0000-00-00 00:00:00',
+  `updated_at` datetime NOT NULL default '0000-00-00 00:00:00',
+  `deleted_at` datetime NOT NULL default '0000-00-00 00:00:00',
+  PRIMARY KEY  (`c_image_profile_id`),
+  KEY `c_member_id` (`c_member_id`),
+  KEY `filename_owner_id_sub` (`filename`(100),`owner_id`),
+  KEY `created_at` (`created_at`)
+) TYPE=MyISAM;
+
+
+CREATE TABLE IF NOT EXISTS `c_image_topic` (
+  `c_image_topic_id` int(11) NOT NULL auto_increment,
+  `c_member_id` int(11) NOT NULL default '0',
+  `filename` text NOT NULL,
+  `filesize` int(11) NOT NULL default '0',
+  `filetype` char(3) NOT NULL default '',
+  `owner_id` int(11) NOT NULL default '0',
+  `comment` text,
+  `tags` varchar(64) default NULL,
+  `image_data` longblob,
+  `created_at` datetime NOT NULL default '0000-00-00 00:00:00',
+  `updated_at` datetime NOT NULL default '0000-00-00 00:00:00',
+  `deleted_at` datetime NOT NULL default '0000-00-00 00:00:00',
+  PRIMARY KEY  (`c_image_topic_id`),
+  KEY `c_member_id` (`c_member_id`),
+  KEY `filename_owner_id_sub` (`filename`(100),`owner_id`),
+  KEY `created_at` (`created_at`)
+) TYPE=MyISAM;
+
+
+CREATE TABLE IF NOT EXISTS `c_image_album` (
+  `c_image_album_id` int(11) NOT NULL auto_increment,
+  `c_member_id` int(11) NOT NULL default '0',
+  `filename` text NOT NULL,
+  `filesize` int(11) NOT NULL default '0',
+  `filetype` char(3) NOT NULL default '',
+  `owner_id` int(11) NOT NULL default '0',
+  `comment` text,
+  `tags` varchar(64) default NULL,
+  `image_data` longblob,
+  `created_at` datetime NOT NULL default '0000-00-00 00:00:00',
+  `updated_at` datetime NOT NULL default '0000-00-00 00:00:00',
+  `deleted_at` datetime NOT NULL default '0000-00-00 00:00:00',
+  PRIMARY KEY  (`c_image_album_id`),
+  KEY `c_member_id` (`c_member_id`),
+  KEY `filename_owner_id_sub` (`filename`(100),`owner_id`),
+  KEY `created_at` (`created_at`)
+) TYPE=MyISAM;
+
+
+CREATE TABLE IF NOT EXISTS `c_album` (
+  `c_album_id` int(11) NOT NULL auto_increment,
+  `c_member_id` int(11) NOT NULL default '0',
+  `subject` text NOT NULL,
+  `body` text NOT NULL ,
+  `tags` varchar(64) default NULL,
+  `created_at` datetime NOT NULL default '0000-00-00 00:00:00',
+  `updated_at` datetime NOT NULL default '0000-00-00 00:00:00',
+  `deleted_at` datetime NOT NULL default '0000-00-00 00:00:00',
+  PRIMARY KEY  (`c_album_id`),
+  KEY `c_member_id` (`c_member_id`),
+  KEY `created_at` (`created_at`)
+) TYPE=MyISAM;
+
+
+
+
 INSERT INTO `c_commu_category` VALUES (1,'地域情報',100,1);
 INSERT INTO `c_commu_category` VALUES (2,'グルメスポット',200,1);
 INSERT INTO `c_commu_category` VALUES (3,'趣味',300,1);
@@ -1048,20 +1288,21 @@ INSERT INTO `c_profile_pref` VALUES (47,'沖縄県',47,26.212401,127.680932,7);
 INSERT INTO `c_profile_pref` VALUES (50,'その他',50,0,0,0);
 -- --------------------------------------------------------
 
-INSERT INTO `c_review_category` VALUES (1,'books-jp','和書',1);
-INSERT INTO `c_review_category` VALUES (2,'books-us','洋書',2);
-INSERT INTO `c_review_category` VALUES (3,'music-jp','CDポピュラー',3);
-INSERT INTO `c_review_category` VALUES (4,'classical-jp','CDクラシック',4);
-INSERT INTO `c_review_category` VALUES (5,'dvd-jp','DVD',5);
-INSERT INTO `c_review_category` VALUES (6,'videogames-jp','ゲーム',6);
-INSERT INTO `c_review_category` VALUES (7,'software-jp','ソフトウェア',7);
-INSERT INTO `c_review_category` VALUES (8,'electronics-jp','エレクトロニクス',8);
-INSERT INTO `c_review_category` VALUES (9,'kitchen-jp','ホーム＆キッチン',9);
-INSERT INTO `c_review_category` VALUES (10,'toys-jp','おもちゃ＆ホビー',10);
-INSERT INTO `c_review_category` VALUES (11,'sporting-goods-jp','スポーツ',11);
-INSERT INTO `c_review_category` VALUES (12,'hpc-jp','ヘルス＆ビューティー',12);
-INSERT INTO `c_review_category` VALUES (13,'watches-jp','時計',13);
-INSERT INTO `c_review_category` VALUES (14,'baby-jp','ベビー＆マタニティ',14);
+INSERT INTO `c_review_category` VALUES (1,'Books','和書',1);
+INSERT INTO `c_review_category` VALUES (2,'ForeignBooks','洋書',2);
+INSERT INTO `c_review_category` VALUES (3,'Music','CDポピュラー',3);
+INSERT INTO `c_review_category` VALUES (4,'Classical','CDクラシック',4);
+INSERT INTO `c_review_category` VALUES (5,'DVD','DVD',5);
+INSERT INTO `c_review_category` VALUES (6,'VideoGames','ゲーム',6);
+INSERT INTO `c_review_category` VALUES (7,'Software','ソフトウェア',7);
+INSERT INTO `c_review_category` VALUES (8,'Electronics','エレクトロニクス',8);
+INSERT INTO `c_review_category` VALUES (9,'Kitchen','キッチン',9);
+INSERT INTO `c_review_category` VALUES (10,'Toys','おもちゃ＆ホビー',10);
+INSERT INTO `c_review_category` VALUES (11,'SportingGoods','スポーツ',11);
+INSERT INTO `c_review_category` VALUES (12,'HealthPersonalCare','ヘルス＆ビューティー',12);
+INSERT INTO `c_review_category` VALUES (13,'Watches','時計',13);
+INSERT INTO `c_review_category` VALUES (14,'Baby','ベビー＆マタニティ',14);
+INSERT INTO `c_review_category` VALUES (15,'Apparel','アパレル＆シューズ',15);
 -- --------------------------------------------------------
 
 INSERT INTO `c_siteadmin` VALUES (1,'inc_page_footer_before','<a href=\"?m=pc&amp;a=page_o_sns_kiyaku\" target=\"_blank\">利用規約</a> <a href=\"?m=pc&amp;a=page_o_sns_privacy\" target=\"_blank\">プライバシーポリシー</a> <a href=\"?m=pc&amp;a=page_o_sns_help\" target=\"_blank\">ヘルプ</a> <a href=\"http://usagi.mynets.jp/\" target=\"_blank\">Usagi Projectとは</a>',NOW());
