@@ -31,12 +31,13 @@ class ktai_page_c_bbs extends OpenPNE_Action
     function execute($requests)
     {
         $u  = $GLOBALS['KTAI_C_MEMBER_ID'];
-        
+
 
         // --- リクエスト変数
         $target_c_commu_topic_id = $requests['target_c_commu_topic_id'];
-        $direc = $requests['direc'];
-        $page = $requests['page'];
+        $direc      = $requests['direc'];
+        $page       = $requests['page'];
+        $sort_order = $requests['sort_order'];
         // ----------
 
         $page_size = 5;
@@ -52,10 +53,19 @@ class ktai_page_c_bbs extends OpenPNE_Action
         $MyDisplayTemplate = getMyDisplay($c_member['mobile_view']);
         $this->set('MyDisplayTemplate',$MyDisplayTemplate['template_foldername']);
         //トピックのコメントリスト
-        $list = k_p_c_bbs_c_commu_topic_comment_list4c_c_commu_topic_id($target_c_commu_topic_id, $u, $page_size, $page);
+        $list = k_p_c_bbs_c_commu_topic_comment_list4c_c_commu_topic_id($target_c_commu_topic_id,
+                                                                        $u,
+                                                                        $page_size,
+                                                                        $page,
+                                                                        $sort_order
+                                                                        );
+        //sort_orderをつける
+        $this->set("sort_order", $sort_order);
         $this->set("c_commu_topic_comment_list", $list[0]);
         $this->set("is_prev", $list[1]);
         $this->set("is_next", $list[2]);
+        //print_r($list);
+
         //トピック名
         $this->set("c_commu_topic_name", k_p_c_bbs_c_commu_topic_name4c_commu_topic_id($target_c_commu_topic_id));
         //トピックID,トピック
@@ -66,7 +76,7 @@ class ktai_page_c_bbs extends OpenPNE_Action
         $c_commu = k_p_c_bbs_c_commu4c_commu_topic_id($target_c_commu_topic_id);
         $c_commu_id = $c_commu['c_commu_id'];
         $this->set("c_commu", $c_commu);
-    
+
         //--- 権限チェック
         //コミュニティの存在の有無
         if (!$c_commu) {
@@ -96,14 +106,30 @@ class ktai_page_c_bbs extends OpenPNE_Action
             $mail_address = "t{$target_c_commu_topic_id}"."@".MAIL_SERVER_DOMAIN;
         }
         $mail_address = urlencode(MAIL_ADDRESS_PREFIX) . $mail_address;
-        $this->set("mail_address", $mail_address);
-    if (MAIL_ADDRESS_HASHED) {
+        if (MAIL_ADDRESS_HASHED) {
             $mail_address2 = "et{$target_c_commu_topic_id}-".t_get_user_hash($u)."@".MAIL_SERVER_DOMAIN;
         } else {
             $mail_address2 = "et{$target_c_commu_topic_id}"."@".MAIL_SERVER_DOMAIN;
         }
         $mail_address2 = urlencode(MAIL_ADDRESS_PREFIX) . $mail_address2;
+        if($GLOBALS['__Framework']['ktai_carrier'] == 'docomo') {
+            $gps_address = OPENPNE_URL.'gmaps/gpsdocomo.php/'.$GLOBALS['KTAI_URL_TAIL'].'/'.$mail_address;
+            $gps_address2 = OPENPNE_URL.'gmaps/gpsdocomo.php/'.$GLOBALS['KTAI_URL_TAIL'].'/'.$mail_address2;
+            $gps_type = 'docomo';
+        } elseif($GLOBALS['__Framework']['ktai_carrier'] == 'au') {
+            $gps_address = 'device:gpsone?url='.OPENPNE_URL.'gmaps/gpsau.php/'.$GLOBALS['KTAI_URL_TAIL'].'/'.$mail_address.'&ver=1&datum=0&unit=1&acry=0&number=0';
+            $gps_address2 = 'device:gpsone?url='.OPENPNE_URL.'gmaps/gpsau.php/'.$GLOBALS['KTAI_URL_TAIL'].'/'.$mail_address2.'&ver=1&datum=0&unit=1&acry=0&number=0';
+            $gps_type = 'au';
+        } elseif($GLOBALS['__Framework']['ktai_carrier'] == 'softbank') {
+            $gps_address = 'location:auto?url='.OPENPNE_URL.'gmaps/gpssoftbank.php/'.$GLOBALS['KTAI_URL_TAIL'].'/'.$mail_address;
+            $gps_address2 = 'location:auto?url='.OPENPNE_URL.'gmaps/gpssoftbank.php/'.$GLOBALS['KTAI_URL_TAIL'].'/'.$mail_address2;
+            $gps_type = 'softbank';
+        }
+        $this->set("mail_address", $mail_address);
         $this->set("mail_address2", $mail_address2);
+        $this->set('gps_address', $gps_address);
+        $this->set('gps_address2', $gps_address2);
+        $this->set('gps_type', $gps_type);
         return 'success';
     }
 }
